# Used by ht1 and grid calculations to calculate a predominance diagram based on the 'predominance' criterion.
# This version of ht1.inc also lists all minerals with SI>=0 as 'carry variables.
# Providing 'out T' is included in the input file, then a list of all minerals that do or should precipitate during the
# calculations will be sent to the log file. This can be used to identify those minerals that are not significant and so
# could be omitted from future calculations, thus speeding up calculations.
#
PRINT
   -reset false
PHASES
Fix_H+
   H+ = H+
   log_k 0.0
SELECTED_OUTPUT 1
   -high_precision true
   -reset false
USER_PUNCH 1
-headings
-start
1 small = 1e-12
10 ns = 0
20 nout1 = 0
30 nout2 = 0
40 nout3 = 0
50 main$ = "<mainspecies>"
60 IF (STEP_NO = 0) THEN 370 ELSE 70
70 totel = SYS(main$, n, n$, t$, moles)
80 h2o = TOT("water")

90 REM Filter out gases
100 FOR i = 1 TO n
110   IF (moles(i) <= small) THEN 190
130   IF (INSTR(n$(i), "(g)") > 0) THEN 180
140   PUNCH n$(i), moles(i)/h2o
#150  PRINT i, n$(i), moles(i)/h2o
160   nout1 = nout1 + 1
170   IF (nout1 >= 3) THEN 190
180 NEXT i

190 REM no type2's

200 IF (SI("H2(g)") > 0) THEN 210 ELSE 230
210 PUNCH "H2(g) > 1 atm", 10^SI("H2(g)")
220 nout3 = nout3 + 1
230 IF (SI("O2(g)") > -0.677) THEN 240 ELSE 260 # you may prefer 1 atm but if so, use '>1e-12' here, say, so you can set ymax = 0
240 PUNCH "O2(g) > 0.21 atm", 10^SI("O2(g)")
250 nout3 = nout3 + 1
260 IF (SI("CH4(g)") > 0) THEN 270 ELSE 290
270 PUNCH "CH4(g) > 1 atm", 10^SI("CH4(g)")
280 nout3 = nout3 + 1

# 4. carry variables, SI>=0
290 nout4 = 0
291 simax = SYS("phases",np,np$,tp$,sis)
292 FOR i = 1 to np
#293 IF (sis(i) > 1e-12) THEN 299
294 IF (sis(i) < -1e-12) THEN 299
296 IF (INSTR(np$(i),"(g)") > 0) THEN 299
297 PUNCH np$(i), sis(i)
298 nout4=nout4+1
299 NEXT i

# system variables
300 po2 = SI("O2(g)")
310 ph2 = SI("H2(g)")
320 ph = -LA("H+")
330 pe = -LA("e-")
340 PUNCH "pH", ph, "pe", pe, "PO2", po2, "PH2", ph2, "temp", TC
350 nout5 = 5
360 PUNCH nout1, nout2, nout3, nout4, nout5
370 END
