# Used to generate data for a %species vs pH plot.
# The 'mainSpecies' keyword in the input file is used to set the main species (sets the "<mainspecies>" tag).
# This can be an 'element' (all master species), 'element(valence)' (a secondary master species), 'aq' for all aqueous species,
# 'ex' for exchange species, 'surf' for surface species, 's_s' for all solid solution components, 'gas' for all gases, and 'all'
# for all types of species of all elements.
# Writes successive 'species names-value' pairs to the 'out' file.
# These are plotted with a custom plot.
# The species always starts with the x-axis variable (here pH) then all the other main component
# species in descending abundance order returning log10(concns) for all species found.
# Line 280 filters out some H and O species - modify this or line 1100 to filter out other unwanted species.
#
# The input file
# ==============
# "<mainspecies>" must be set to the 'element' of interest, or "elements", "aq" etc for difft subset, or 'all' for all species.
# 'customXcolumn' must be set to the column where the pH is written, as here in column 2
#
PRINT
  -reset false   # change to 'true' if PRINT'ed output from Phreeqc wanted

SELECTED_OUTPUT
  -high_precision       true
  -reset                false

USER_PUNCH 1
    -headings 
    -start
 1  small = 1e-12
 10 IF(STEP_NO <= 0) THEN 430
 20 DIM nel$(1)
 30 nel$(1) = "<mainspecies>"
 40 nel = 1
 50 nfound = 0
 60 maxfound = 10000
 70 DIM found$(maxfound)
 80 leftparen$ = "("
 90 IF(nel$(1) <> "all") THEN 110
100 totalmol = SYS("elements", nel, nel$, tel$, molesel)
110 FOR k = 1 TO nel
120    main$ = nel$(k)
130    PRINT "------------------------------------------------------------------------------"
140    PRINT "Main element = ", TRIM(main$)
150    IF(k = 1) THEN PUNCH "pH", -LA("H+")
160    lp = INSTR(main$, leftparen$)
170    REM only primary master species
180    IF(lp > 0) THEN 420
190    totel = SYS(main$, n, n$, t$, moles)
200    IF(totel <= 0) THEN 420
210    REM
220    FOR i = 1 TO n
230       species$ = n$(i)
240       PRINT
250       PRINT LTRIM(STR$(i))+".", species$, "'"+t$(i)+"'", moles(i), "mol "+main$+"/kgw"
260       GOSUB 2000
270       IF(st > 0) THEN moles(i) = moles(i)/st
280       IF(MID$(n$(i), 1, 2) = "H(" OR MID$(n$(i), 1, 2) = "O(" OR n$(i) = "O" OR n$(i) = "H") THEN 110
290       GOSUB 1000
300       IF(isnew = 0) THEN 400
310       IF(t$(i) = "equi") THEN 320 ELSE 360
320       IF(moles(i) > small) THEN 330 ELSE 390
330       IF(INSTR(n$(i), "(g)") = 0) THEN PUNCH n$(i)+"(s)", LOG10(moles(i)/TOT("water")) ELSE PUNCH n$(i), LOG10(moles(i)/TOT("water"))
340       REM PUNCH n$(i), LOG10(moles(i)/TOT("water"))
350       GOTO 400
360       IF(moles(i) > 0) THEN PUNCH n$(i), LOG10(moles(i)/TOT("water")) ELSE 390
370       GOTO 400
380       REM -99999 is PhreePlot UNDEFINED value so gives a break whereas -999 is a large -ve value which will show a 'plunge'
390       PUNCH n$(i), -999
400    NEXT i
410    PRINT
420 NEXT k
430 END

1000 REM SUBROUTINES

1010 REM
1020 REM checks if species is already in the output list or not
1030 REM
1040 isnew = 0
1050 FOR icheck = 1 TO nfound
1060 IF(species$ = found$(icheck)) THEN 1150
1070 NEXT icheck
1080 REM not found so add it
1090 REM filter out any species you do NOT want to plot
1100 REM IF(species$ = "H+" OR species$ = "OH-") THEN 1130
1110 IF(nfound >= maxfound) THEN 1150
1120 nfound = nfound + 1
1130 found$(nfound) = species$
1140 isnew = 1
1150 RETURN
1160 END

2000 REM
2020 REM gets stoichiometry of element in aq or solid species
2030 REM
2040 sptype$ = SPECIES_FORMULA$(species$, count, elt$, coef)
2050 st = 0
2060 IF sptype$ = "none" THEN 2150 ELSE 2080
2070 REM
2080 REM aq species
2090 FOR j = 1 TO count
2100    IF(main$ = elt$(j)) THEN 2120
2110 NEXT j
2120 PRINT species$, "contains", LTRIM(STR$(coef(j))), elt$(j)
2130 GOTO 2220
2140 REM
2150 REM pure phases
2160 phase$ = PHASE_FORMULA$(species$, count, elt$, coef)
2170 FOR j = 1 TO count
2180    IF(main$ = elt$(j)) THEN 2210
2190 NEXT j
2200 GOTO 2220
2210 PRINT species$, "("+phase$+")", "contains", LTRIM(STR$(coef(j))), elt$(j)
2220 RETURN
2230 END
   -end

